<?php
/*
 * @version $Id: graph.send.php 17152 2012-01-24 11:22:16Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

Session ::checkLoginUser();

if (isset($_GET["switchto"])) {
   $_SESSION['glpigraphtype'] = $_GET["switchto"];
   Html::back();
}

if ($uid=Session::getLoginUserID(false) && isset($_GET["file"])) {
   list($userID,$filename)=explode("_",$_GET["file"]);
   if ($userID==$uid && file_exists(GLPI_GRAPH_DIR."/".$_GET["file"])) {
      list($fname,$extension)=explode(".",$filename);

      Toolbox::sendFile(GLPI_GRAPH_DIR."/".$_GET["file"], 'glpi.'.$extension);
   } else {
      Html::displayErrorAndDie($LANG['document'][45],true);
   }
}
?>